@@ -61,3 +61,7 @@ def get_create_procedure_sql_path():
 
 def get_drop_procedure_sql_path():
     return os.path.join(common_sql_path(), "drop_procedure.sql")
+
+
+def get_app_config_path():
+    return os.path.join(docs_path(), "config_info.json")
